{% if node.has_children %}
<a class="dropdown-toogle" href="{{node.get_absolute_url}}">{{node.label}}</a>
{% else %}
<a href="{{node.get_absolute_url}}" {% if node.is_external %}target=_blank{% endif %}>{{node.label}}</a>
{% endif %}
