# -*- coding: utf-8 -*-
"""Applicaion for unit testing"""

from __future__ import unicode_literals

from django.apps import AppConfig

class CoopCmsTestAppConfig(AppConfig):
    name = 'coop_cms.apps.test_app'
    verbose_name = "coop CMS > App for unit test"
