{% extends "colorbox/popup_form_base.html" %}
{% load i18n %}
{% block title %}{% trans "Upload document" %}{% endblock %}
{% block form_url %}{% url "coop_cms_upload_doc" %}{% endblock %}
{% block form_ok %}{% trans "Add" %}{% endblock %}