{% extends "admin/change_list.html" %} {% load i18n %}
{% block object-tools-items %}
    {{ block.super }}
    <li>
        <a class="historylink" href="{% url 'admin:coop_cms_navtree_changelist' %}">{% trans "Navigation trees" %}</a>
    </li>
    {{ form.errors }}
{% endblock %}